# GHTRENDING

![pypi](https://img.shields.io/pypi/v/ghtrending.svg)

## Overview

**GHTRENDING** is a commandline tool for explore GitHub trending, includes developers and repository.

<p align="center">
  <img width="600" src="https://github.com/chinsyo/ghtrending/blob/master/screenshot.svg">
</p>

## INSTALLATION
```shell
// package (recommend)
pip3 install ghtrending

// source
git clone https://github.com/chinsyo/ghtrending.git && cd ghtrending
```

## USAGE
```shell
// package (recommend)
python3 -m ghtrending

// source
python3 ghtrending/ghtrending.py
```
